pub struct EnvelopeData {
pub from: Option<String>,
pub rcpt: Vec<String>,
pub ip: Option<String>,
pub user: Option<String>,
pub helo: Option<String>,
pub hostname: Option<String>,
pub file_path: Option<String>,
pub body_block: bool,
pub additional_headers: HashMap<String, String>,
}Fields
from: Option<String>Sender email address
rcpt: Vec<String>Recipients email addresses
ip: Option<String>Optional IP address of the sender
user: Option<String>Optional IP of the sender
helo: Option<String>Optional HELO string
hostname: Option<String>Optional hostname
file_path: Option<String>Optional file path for local file scanning (File header) When set, the message body is not transmitted and Rspamd reads the file directly from disk This is a significant optimization when client and server are on the same host
body_block: boolRequest rewritten body in response (body_block flag) When enabled, if Rspamd rewrites the message body, it will be returned as a separate part of the reply after the JSON, with Message-Offset header indicating where the body starts
additional_headers: HashMap<String, String>Optional additional headers
Implementations
Sourceimpl EnvelopeData
impl EnvelopeData
Sourcepub fn builder() -> EnvelopeDataBuilder<((), (), (), (), (), (), (), (), ())>
pub fn builder() -> EnvelopeDataBuilder<((), (), (), (), (), (), (), (), ())>
Create a builder for building EnvelopeData.
On the builder, call .from(...)(optional), .rcpt(...)(optional), .ip(...)(optional), .user(...)(optional), .helo(...)(optional), .hostname(...)(optional), .file_path(...)(optional), .body_block(...)(optional), .additional_headers(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of EnvelopeData.