Module protocol

Module protocol 

Re-exports

pub use scan::RspamdScanReply;

Modules

commands
Commands that can be sent to the server
encryption
This module contains encryption functions used by the HTTPCrypt protocol. This encryption is common to x25519 and chacha20-poly1305 as defined in RFC 8439. However, since HTTPCrypt has been designed before RFC being published, it uses a different way to do KEX and to derive shared keys. In general, it relies on hchacha20 for kdf and x25519 for key exchange.
scan